@@ -33,7 +33,7 @@ def test_basic_view(schema, schema_map, expected_result):
     t1 = Table('t1', sa.MetaData(schema=schema),
                sa.Column('col1', sa.Integer(), primary_key=True),
                sa.Column('col2', sa.Integer()))
-    selectable = sa.sql.select([t1])
+    selectable = sa.sql.select(t1)
     view = Table('myview', sa.MetaData(schema=schema))
     create_view = CreateView(view, selectable)
     actual = compile_query(create_view, schema_translate_map=schema_map)
@@ -44,7 +44,7 @@ def test_view_replace():
     expected_result = """
     CREATE OR REPLACE VIEW myview AS SELECT t1.col1, t1.col2 FROM t1
     """
-    selectable = sa.sql.select([t1])
+    selectable = sa.sql.select(t1)
     view = Table('myview', sa.MetaData())
     create_view = CreateView(view, selectable, or_replace=True)
     assert clean(expected_result) == clean(compile_query(create_view))
@@ -54,7 +54,7 @@ def test_view_with_column_names():
     expected_result = """
     CREATE VIEW myview (col3, col4) AS SELECT t1.col1, t1.col2 FROM t1
     """
-    selectable = sa.sql.select([t1])
+    selectable = sa.sql.select(t1)
     view = Table('myview', sa.MetaData(),
                  sa.Column('col3', sa.Integer(), primary_key=True),
                  sa.Column('col4', sa.Integer()))
@@ -65,7 +65,7 @@ def test_view_with_literals():
     expected_result = """
     CREATE VIEW myview (col3) AS SELECT 0 AS anon_1
     """
-    selectable = sa.sql.select((sa.literal(0),))
+    selectable = sa.sql.select(sa.literal(0))
     view = Table('myview', sa.MetaData(),
                  sa.Column('col3', sa.Integer()))
     create_view = CreateView(view, selectable)
@@ -76,7 +76,7 @@ def test_view_with_delimited_identifiers():
     CREATE VIEW "my nice view!" ("col#1", "select") AS
       SELECT t1.col1, t1.col2 FROM t1
     """
-    selectable = sa.sql.select([t1])
+    selectable = sa.sql.select(t1)
     view = Table('my nice view!', sa.MetaData(),
                  sa.Column('col#1', sa.Integer(), primary_key=True),
                  sa.Column('select', sa.Integer()))
@@ -89,7 +89,7 @@ def test_view_with_options():
     t1 = Table('t1', sa.MetaData(),
                sa.Column('col1', sa.Integer(), primary_key=True),
                sa.Column('col2', sa.Integer()))
-    selectable = sa.sql.select([t1])
+    selectable = sa.sql.select(t1)
     view = Table('myview', sa.MetaData())
     create_view = CreateView(view, selectable, options=dict(check_option='local'))
     actual = compile_query(create_view)
@@ -100,7 +100,7 @@ def test_view_with_compiled_select():
     CREATE VIEW myview AS SELECT DISTINCT ON (t1.col2) t1.col1, t1.col2 FROM t1
     """
     selectable = (
-        sa.sql.select([t1]).distinct(t1.c.col2).compile(dialect=postgresql.dialect())
+        sa.sql.select(t1).distinct(t1.c.col2).compile(dialect=postgresql.dialect())
     )
     view = Table("myview", sa.MetaData())
     create_view = CreateView(view, selectable)
@@ -113,13 +113,26 @@ def test_view_with_on_parameter_is_not_none():
     expected_result = """
     CREATE OR REPLACE VIEW myview AS SELECT t1.col1, t1.col2 FROM t1
     """
-    selectable = sa.sql.select([t1])
+    selectable = sa.sql.select(t1)
     view = Table('myview', sa.MetaData())
     with pytest.raises(TypeError):
         create_view = CreateView(
             view, selectable, on=True)  # on is not None
 
 
+@pytest.mark.skipif(sqla_version < Version('2.0.0'),
+                    reason="Only for SQLAlchemy >= 2.0.0")
+def test_view_with_bind_parameter_is_not_none():
+    expected_result = """
+    CREATE OR REPLACE VIEW myview AS SELECT t1.col1, t1.col2 FROM t1
+    """
+    selectable = sa.sql.select(t1)
+    view = Table('myview', sa.MetaData())
+    with pytest.raises(TypeError):
+        create_view = CreateView(
+            view, selectable, bind=True)  # bind is not None
+
+
 def test_drop_basic_view():
     expected_result = """
     DROP VIEW myview
@@ -165,3 +178,14 @@ def test_drop_with_on_parameter_is_not_none():
     view = Table('myview', sa.MetaData())
     with pytest.raises(TypeError):
         DropView(view, on=True)  # on is not None
+
+
+@pytest.mark.skipif(sqla_version < Version('2.0.0'),
+                    reason="Only for SQLAlchemy >= 2.0.0")
+def test_drop_with_bind_parameter_is_not_none():
+    expected_result = """
+    DROP VIEW myview
+    """
+    view = Table('myview', sa.MetaData())
+    with pytest.raises(TypeError):
+        DropView(view, bind=True)  # bind is not None
